Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1548)

Unified Diff: remoting/host/win/security_descriptor.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/win/security_descriptor.h ('k') | remoting/host/win/session_input_injector.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/win/security_descriptor.cc
diff --git a/remoting/host/win/security_descriptor.cc b/remoting/host/win/security_descriptor.cc
index 1085dd119f2775b4d9029f46cbbd8cfcebb875da..886fae9276a1ff5f4e092321e576b61ff7b5b781 100644
--- a/remoting/host/win/security_descriptor.cc
+++ b/remoting/host/win/security_descriptor.cc
@@ -12,7 +12,7 @@
namespace remoting {
ScopedSd ConvertSddlToSd(const std::string& sddl) {
- PSECURITY_DESCRIPTOR raw_sd = NULL;
+ PSECURITY_DESCRIPTOR raw_sd = nullptr;
ULONG length = 0;
if (!ConvertStringSecurityDescriptorToSecurityDescriptor(
base::UTF8ToUTF16(sddl).c_str(), SDDL_REVISION_1, &raw_sd, &length)) {
@@ -28,7 +28,7 @@ ScopedSd ConvertSddlToSd(const std::string& sddl) {
// Converts a SID into a text string.
std::string ConvertSidToString(SID* sid) {
- base::char16* c_sid_string = NULL;
+ base::char16* c_sid_string = nullptr;
if (!ConvertSidToStringSid(sid, &c_sid_string))
return std::string();
@@ -37,11 +37,11 @@ std::string ConvertSidToString(SID* sid) {
return base::UTF16ToUTF8(sid_string);
}
// Returns the logon SID of a token. Returns NULL if the token does not specify
// a logon SID or in case of an error.
ScopedSid GetLogonSid(HANDLE token) {
DWORD length = 0;
- if (GetTokenInformation(token, TokenGroups, NULL, 0, &length) ||
+ if (GetTokenInformation(token, TokenGroups, nullptr, 0, &length) ||
GetLastError() != ERROR_INSUFFICIENT_BUFFER) {
return ScopedSid();
}
@@ -78,15 +78,15 @@ bool MakeScopedAbsoluteSd(const ScopedSd& relative_sd,
DWORD owner_size = 0;
DWORD sacl_size = 0;
if (MakeAbsoluteSD(relative_sd.get(),
- NULL,
+ nullptr,
&absolute_sd_size,
- NULL,
+ nullptr,
&dacl_size,
- NULL,
+ nullptr,
&sacl_size,
- NULL,
+ nullptr,
&owner_size,
- NULL,
+ nullptr,
&group_size) ||
GetLastError() != ERROR_INSUFFICIENT_BUFFER) {
return false;
@@ -37,11 +37,11 @@ std::string ConvertSidToString(SID* sid) {
return base::UTF16ToUTF8(sid_string);
}
-// Returns the logon SID of a token. Returns NULL if the token does not specify
-// a logon SID or in case of an error.
+// Returns the logon SID of a token. Returns nullptr if the token does not
+// specify a logon SID or in case of an error.
ScopedSid GetLogonSid(HANDLE token) {
DWORD length = 0;
« no previous file with comments | « remoting/host/win/security_descriptor.h ('k') | remoting/host/win/session_input_injector.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698